@@ -271,7 +271,7 @@ class TextColumn(ProgressColumn):
         table_column: Optional[Column] = None,
     ) -> None:
         self.text_format = text_format
-        self.justify = justify
+        self.justify: JustifyMethod = justify
         self.style = style
         self.markup = markup
         self.highlighter = highlighter
@@ -343,18 +343,48 @@ class TimeElapsedColumn(ProgressColumn):
 
 
 class TimeRemainingColumn(ProgressColumn):
-    """Renders estimated time remaining."""
+    """Renders estimated time remaining.
+
+    Args:
+        compact (bool, optional): Render MM:SS when time remaining is less than an hour. Defaults to False.
+        elapsed_when_finished (bool, optional): Render time elapsed when the task is finished. Defaults to False.
+    """
 
     # Only refresh twice a second to prevent jitter
     max_refresh = 0.5
 
+    def __init__(
+        self,
+        compact: bool = False,
+        elapsed_when_finished: bool = False,
+        table_column: Optional[Column] = None,
+    ):
+        self.compact = compact
+        self.elapsed_when_finished = elapsed_when_finished
+        super().__init__(table_column=table_column)
+
     def render(self, task: "Task") -> Text:
         """Show time remaining."""
-        remaining = task.time_remaining
-        if remaining is None:
-            return Text("-:--:--", style="progress.remaining")
-        remaining_delta = timedelta(seconds=int(remaining))
-        return Text(str(remaining_delta), style="progress.remaining")
+        if self.elapsed_when_finished and task.finished:
+            task_time = task.finished_time
+            style = "progress.elapsed"
+        else:
+            task_time = task.time_remaining
+            style = "progress.remaining"
+
+        if task_time is None:
+            return Text("--:--" if self.compact else "-:--:--", style=style)
+
+        # Based on https://github.com/tqdm/tqdm/blob/master/tqdm/std.py
+        minutes, seconds = divmod(int(task_time), 60)
+        hours, minutes = divmod(minutes, 60)
+
+        if self.compact and not hours:
+            formatted = f"{minutes:02d}:{seconds:02d}"
+        else:
+            formatted = f"{hours:d}:{minutes:02d}:{seconds:02d}"
+
+        return Text(formatted, style=style)
 
 
 class FileSizeColumn(ProgressColumn):
@@ -375,6 +405,33 @@ class TotalFileSizeColumn(ProgressColumn):
         return Text(data_size, style="progress.filesize.total")
 
 
+class MofNCompleteColumn(ProgressColumn):
+    """Renders completed count/total, e.g. '  10/1000'.
+
+    Best for bounded tasks with int quantities.
+
+    Space pads the completed count so that progress length does not change as task progresses
+    past powers of 10.
+
+    Args:
+        separator (str, optional): Text to separate completed and total values. Defaults to "/".
+    """
+
+    def __init__(self, separator: str = "/", table_column: Optional[Column] = None):
+        self.separator = separator
+        super().__init__(table_column=table_column)
+
+    def render(self, task: "Task") -> Text:
+        """Show completed/total."""
+        completed = int(task.completed)
+        total = int(task.total)
+        total_width = len(str(total))
+        return Text(
+            f"{completed:{total_width}d}{self.separator}{total}",
+            style="progress.download",
+        )
+
+
 class DownloadColumn(ProgressColumn):
     """Renders file size downloaded and total, e.g. '0.5/2.3 GB'.
 
@@ -400,7 +457,9 @@ class DownloadColumn(ProgressColumn):
             )
         else:
             unit, suffix = filesize.pick_unit_and_suffix(
-                total, ["bytes", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"], 1000
+                total,
+                ["bytes", "kB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
+                1000,
             )
         completed_ratio = completed / unit
         total_ratio = total / unit
@@ -475,7 +534,7 @@ class Task:
     """Optional[float]: The last speed for a finished task."""
 
     _progress: Deque[ProgressSample] = field(
-        default_factory=deque, init=False, repr=False
+        default_factory=lambda: deque(maxlen=1000), init=False, repr=False
     )
 
     _lock: RLock = field(repr=False, default_factory=RLock)
@@ -588,12 +647,7 @@ class Progress(JupyterMixin):
             refresh_per_second is None or refresh_per_second > 0
         ), "refresh_per_second must be > 0"
         self._lock = RLock()
-        self.columns = columns or (
-            TextColumn("[progress.description]{task.description}"),
-            BarColumn(),
-            TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
-            TimeRemainingColumn(),
-        )
+        self.columns = columns or self.get_default_columns()
         self.speed_estimate_period = speed_estimate_period
 
         self.disable = disable
@@ -613,6 +667,37 @@ class Progress(JupyterMixin):
         self.print = self.console.print
         self.log = self.console.log
 
+    @classmethod
+    def get_default_columns(cls) -> Tuple[ProgressColumn, ...]:
+        """Get the default columns used for a new Progress instance:
+           - a text column for the description (TextColumn)
+           - the bar itself (BarColumn)
+           - a text column showing completion percentage (TextColumn)
+           - an estimated-time-remaining column (TimeRemainingColumn)
+        If the Progress instance is created without passing a columns argument,
+        the default columns defined here will be used.
+
+        You can also create a Progress instance using custom columns before
+        and/or after the defaults, as in this example:
+
+            progress = Progress(
+                SpinnerColumn(),
+                *Progress.default_columns(),
+                "Elapsed:",
+                TimeElapsedColumn(),
+            )
+
+        This code shows the creation of a Progress display, containing
+        a spinner to the left, the default columns, and a labeled elapsed
+        time column.
+        """
+        return (
+            TextColumn("[progress.description]{task.description}"),
+            BarColumn(),
+            TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
+            TimeRemainingColumn(),
+        )
+
     @property
     def console(self) -> Console:
         return self.live.console
@@ -645,6 +730,8 @@ class Progress(JupyterMixin):
     def stop(self) -> None:
         """Stop the progress display."""
         self.live.stop()
+        if not self.console.is_interactive:
+            self.console.print()
 
     def __enter__(self) -> "Progress":
         self.start()
@@ -764,7 +851,7 @@ class Progress(JupyterMixin):
             task = self._tasks[task_id]
             completed_start = task.completed
 
-            if total is not None:
+            if total is not None and total != task.total:
                 task.total = total
                 task._reset()
             if advance is not None:
@@ -785,8 +872,6 @@ class Progress(JupyterMixin):
             popleft = _progress.popleft
             while _progress and _progress[0].timestamp < old_sample_time:
                 popleft()
-            while len(_progress) > 1000:
-                popleft()
             if update_completed > 0:
                 _progress.append(ProgressSample(current_time, update_completed))
             if task.completed >= task.total and task.finished_time is None:
@@ -1013,10 +1098,7 @@ if __name__ == "__main__":  # pragma: no coverage
 
     with Progress(
         SpinnerColumn(),
-        TextColumn("[progress.description]{task.description}"),
-        BarColumn(),
-        TextColumn("[progress.percentage]{task.percentage:>3.0f}%"),
-        TimeRemainingColumn(),
+        *Progress.get_default_columns(),
         TimeElapsedColumn(),
         console=console,
         transient=True,
